#!/usr/bin/perl 

###############################################################
# script de dtection des alertes sur les bases de donnes rrd
# (charge rseau)
# par bruno boiget (CETIAD)
# #############################################################

use RRDs;
use strict;
use Getopt::Std;

# gestion d'alarme dans une base rrd
my $alerte = 0;
my $pair = 0;
my $output = 0;
my $input = 0;
my $seuil = 0;
my $interf = "";
my $fic_alerte = "/usr/share/ead/rrd/alerte.tmp";
my $rep_bas_rrd = "/usr/share/ead/rrd/";
my $rep_scripts= "/usr/share/eole";
			

# A chaque appel du script, la base de donnes et le seuil limite sont passs en paramtre
use vars qw($opt_i $opt_s);

# message d'aide :
my $help = "\n usage : alerte.pl -i<interface> -s<seuil de charge>";

# Nous lisons la liste des options

unless( getopts('i:s:') )
{
	print STDERR $help;
	exit 0;
}

if( $opt_i )
{
	$interf = $opt_i;
}
unless( $opt_i )
{
	print STDERR $help;
	print STDERR "\n*** Erreur : Spcifiez l'interface rseau\n             (eth0,eth1,...,squid)\n";
	exit 0;
}

if( $opt_s )
{
	$seuil = $opt_s;
}
unless( $opt_s )
{
	print STDERR $help;
	print STDERR "\n*** Erreur : Spcifiez le seuil de surcharge\n";
	exit 0;
}	


# print "\n arguments: ", $interf, " - ", $seuil, ".\n";

# on rcupre la moyenne sur les 5 dernires minutes (dernires valeurs enregistres)
my ($start,$step,$names,$data) = RRDs::fetch ("$rep_bas_rrd/".$interf.".rrd", "--start=-900", "AVERAGE");


# test des valeurs rcuperes
 foreach my $line (@$data[3])
 {
	foreach my $val (@$line) 
	{
		if ($pair == 1)
		{
			$pair = 0
		}
		else
		{
			$pair = 1
		}


		if ( ("$interf" eq "squid_system") && ($pair == 0) )
		{
			# cas spcial : cas de la charge cpu/mmoire squid
			# ici, les 2 valeurs ont des chelles diffrentes
			#                         
			# on ramne la valeur de la mmoire  un pourcentage
			# pour avoir le mme seuil que pour le cpu
			#
			# on rcupre la taille mmoire
		
			my $mem_physique = `cat /proc/meminfo | grep MemTotal: |mawk -F " " '{print $2}'`;
			# on passe la valeur de Koctets  octets
			$val = $val * 1000;
			# et on calcule le % d'occupation
			$val = ($val * 100) / $mem_physique;
		}
		
		#printf "%d \n", $val;
		if (($seuil - $val) le 0)
		{
			$alerte = 1;
		}
	}
}

if ($alerte == 1) {
	print "\n !!! Attention : ", $interf, " actuellement en surcharge !!! \n";
	# vrification de la dure de la surcharge	
	# on vrifie la moyenne de charge sur les 20 dernires minutes
	# si elle est suprieure ou gale au seuil -> alerte visuelle
	# les donnes retournes par rrdool tant alternes en entre/sortie,
	# on utilise un flag pair/impair pour pouvoir les diffrencier
	
	# calcul de la moyenne
	# on ajoute les 4 dernires moyennes (sur 5 minutes)
	foreach my $line (@$data[0,1,2,3])
	{
		foreach my $val (@$line)
		{
			# printf "%d \n", $val;
			
			if ($pair == 1)
			{
				$pair = 0
			}
			else
			{
				$pair = 1
			}
			
			if ($pair == 1)
			{
				$input += $val;
			}
			else
			{
				$output += $val;
			}	
		}
	}
	# puis, on divise le tout par quatre pour obtenir la moyenne sur les 20 dernires minutes
	# (les valeurs tant en octets/s, on divise par 1000 pour obtenir des Ko/s)
	$input = $input/4;
	$output = $output/4;
	printf "\n Moyennes sur les 20 dernires minutes \n -- Entre : %6.1f Ko/s \n -- Sortie : %6.1f Ko/s \n\n", ($input/1000), ($output/1000);

	# Si la moyenne sur 20 minutes dpasse le seuil et qu'il n'existe pas encore de fichier d'alerte :
	# on remonte l'alerte
	
	if ( ($input > $seuil) || ($output > $seuil) )
	{
		#  moins que l'alerte soit dj dclare
		unless ( open (FIC_TEST, "$fic_alerte" ) )
		{
			# appel du script permettant la remonte de l'alerte dans les logs (Zephir)
			system("$rep_scripts/logalerte.sh", "$interf", "dbut") == 0 || die "erreur lors du log zephir";

			# on cr un fichier temporaire pour signaler l'alerte
			open (FIC_OUT, ">$fic_alerte" ) || die "impossible de crer le fichier $fic_alerte" ;
			# on stocke la date (timestamp) de l'alerte dans le fichier
			# Cette date n'est pas utilise actuellement
			print FIC_OUT time,"\n";
		}
	}
}
else
{
	print "\n charge normale pour ",$interf, "\n";
	# on dsactive l'alerte si elle existait
	if ( open (FIC_TEST, "$fic_alerte" ) )
	{
		#  on tait auparavant en alerte => on annule celle-ci en supprimant le fichier temporaire
		unlink ($fic_alerte);
		# on signale la fin de l'alerte dans les logs
		system("$rep_scripts/logalerte.sh", "$interf", "fin") == 0 || die "erreur lors du log zephir";
	}
}
